@@ -52,7 +52,7 @@ void sfdp_layout(GraphInterface& g, boost::any pos, boost::any vweight,
     double mu = python::extract<double>(spring_parms[4]);
     double mu_p = python::extract<double>(spring_parms[5]);
     group_map_t groups =
-        any_cast<group_map_t>(python::extract<any>(spring_parms[6]));
+        any_cast<group_map_t>(python::extract<any>(spring_parms[6])());
 
     if(vweight.empty())
         vweight = vweight_map_t();
