@@ -3,7 +3,7 @@
 #
 # graph_tool -- a general graph manipulation python module
 #
-# Copyright (C) 2006-2018 Tiago de Paula Peixoto <tiago@skewed.de>
+# Copyright (C) 2006-2019 Tiago de Paula Peixoto <tiago@skewed.de>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -60,7 +60,7 @@ __all__ = ["local_clustering", "global_clustering", "extended_clustering",
            "motifs", "motif_significance"]
 
 
-def local_clustering(g, prop=None, undirected=True):
+def local_clustering(g, weight=None, prop=None, undirected=True):
     r"""
     Return the local clustering coefficients for all vertices.
 
@@ -68,7 +68,9 @@ def local_clustering(g, prop=None, undirected=True):
     ----------
     g : :class:`~graph_tool.Graph`
         Graph to be used.
-    prop : :class:`~graph_tool.PropertyMap` or string, optional
+    weight : :class:`~graph_tool.EdgePropertyMap`, optional (default: None)
+        Edge weights. If omitted, a constant value of 1 will be used.
+    prop : :class:`~graph_tool.VertexPropertyMap` or string, optional
         Vertex property map where results will be stored. If specified, this
         parameter will also be the return value.
     undirected : bool (default: True)
@@ -77,7 +79,7 @@ def local_clustering(g, prop=None, undirected=True):
 
     Returns
     -------
-    prop : :class:`~graph_tool.PropertyMap`
+    prop : :class:`~graph_tool.VertexPropertyMap`
         Vertex property containing the clustering coefficients.
 
     See Also
@@ -105,23 +107,17 @@ def local_clustering(g, prop=None, undirected=True):
     .. math::
        c'_i = 2c_i.
 
-    The implemented algorithm runs in :math:`O(|V|\left< k\right>^2)` time,
-    where :math:`\left< k\right>` is the average out-degree.
+    The implemented algorithm runs in :math:`O(|V|\left<k^2\right>)` time,
+    where :math:`\left<k^2\right>` is second moment of the degree distribution.
 
     If enabled during compilation, this algorithm runs in parallel.
 
     Examples
     --------
-    .. testcode::
-       :hide:
-
-       np.random.seed(42)
-       gt.seed_rng(42)
-
-    >>> g = gt.random_graph(1000, lambda: (5,5))
+    >>> g = gt.collection.data["karate"]
     >>> clust = gt.local_clustering(g)
     >>> print(gt.vertex_average(g, clust))
-    (0.008177777777777779, 0.00042080229075093...)
+    (0.5706384782..., 0.05869813676...)
 
     References
     ----------
@@ -134,18 +130,20 @@ def local_clustering(g, prop=None, undirected=True):
         prop = g.new_vertex_property("double")
     if g.is_directed() and undirected:
         g = GraphView(g, directed=False, skip_properties=True)
-    _gt.local_clustering(g._Graph__graph, _prop("v", g, prop))
+    _gt.local_clustering(g._Graph__graph, _prop("v", g, prop),
+                         _prop("e", g, weight))
     return prop
 
 
-def global_clustering(g):
-    r"""
-    Return the global clustering coefficient.
+def global_clustering(g, weight=None):
+    r"""Return the global clustering coefficient.
 
     Parameters
     ----------
     g : :class:`~graph_tool.Graph`
         Graph to be used.
+    weight : :class:`~graph_tool.EdgePropertyMap`, optional (default: None)
+        Edge weights. If omitted, a constant value of 1 will be used.
 
     Returns
     -------
@@ -167,33 +165,37 @@ def global_clustering(g):
        c = 3 \times \frac{\text{number of triangles}}
                           {\text{number of connected triples}}
 
-    The implemented algorithm runs in :math:`O(|V|\left< k\right>^2)` time,
-    where :math:`\left< k\right>` is the average (total) degree.
+    If weights are given, the following definition is used:
+
+    .. math::
+       c = \frac{\mathrm{Tr}{{\boldsymbol A}^3}}{\sum_{i\ne j}[{\boldsymbol A}^2]_{ij}},
+
+    where :math:`\boldsymbol A` is the weighted adjacency matrix, and it is
+    assumed that the weights are normalized, i.e. :math:`A_{ij} \le 1`.
+
+    The implemented algorithm runs in time :math:`O(|V|\left<k^2\right>)`,
+    where :math:`\left< k^2\right>` is the second moment of the degree
+    distribution.
 
     If enabled during compilation, this algorithm runs in parallel.
 
     Examples
     --------
-    .. testcode::
-       :hide:
-
-       np.random.seed(42)
-       gt.seed_rng(42)
-
-    >>> g = gt.random_graph(1000, lambda: (5,5))
+    >>> g = gt.collection.data["karate"]
     >>> print(gt.global_clustering(g))
-    (0.008177777777777779, 0.0004212235142651...)
+    (0.2556818181..., 0.06314746595...)
 
     References
     ----------
     .. [newman-structure-2003] M. E. J. Newman, "The structure and function of
        complex networks", SIAM Review, vol. 45, pp. 167-256, 2003,
        :doi:`10.1137/S003614450342480`
+
     """
 
     if g.is_directed():
         g = GraphView(g, directed=False, skip_properties=True)
-    c = _gt.global_clustering(g._Graph__graph)
+    c = _gt.global_clustering(g._Graph__graph, _prop("e", g, weight))
     return c
 
 
@@ -205,18 +207,18 @@ def extended_clustering(g, props=None, max_depth=3, undirected=False):
     ----------
     g : :class:`~graph_tool.Graph`
         Graph to be used.
-    props : list of :class:`~graph_tool.PropertyMap` objects, optional
+    props : list of :class:`~graph_tool.VertexPropertyMap` objects (optional, default: ``None``)
         list of vertex property maps where results will be stored. If specified,
         this parameter will also be the return value.
-    max_depth : int, optional
-        Maximum clustering order (default: 3).
-    undirected : bool, optional
+    max_depth : int (optional, default: ``3``)
+        Maximum clustering order.
+    undirected : boolean (optional, default: ``False``)
         Calculate the *undirected* clustering coefficients, if graph is directed
         (this option has no effect if the graph is undirected).
 
     Returns
     -------
-    prop : list of :class:`~graph_tool.PropertyMap` objects
+    prop : list of :class:`~graph_tool.VertexPropertyMap` objects
         List of vertex properties containing the clustering coefficients.
 
     See Also
@@ -252,22 +254,16 @@ def extended_clustering(g, props=None, max_depth=3, undirected=False):
 
     Examples
     --------
-    .. testcode::
-       :hide:
-
-       np.random.seed(42)
-       gt.seed_rng(42)
-
-    >>> g = gt.random_graph(1000, lambda: (5,5))
+    >>> g = gt.collection.data["karate"]
     >>> clusts = gt.extended_clustering(g, max_depth=5)
     >>> for i in range(0, 5):
     ...    print(gt.vertex_average(g, clusts[i]))
     ...
-    (0.0050483333333333335, 0.0004393940240073...)
-    (0.024593787878787878, 0.0009963004021144...)
-    (0.11238924242424242, 0.001909615401971...)
-    (0.40252272727272725, 0.003113987400030...)
-    (0.43629378787878786, 0.003144159256565...)
+    (0.5706384782076..., 0.05869813676256...)
+    (0.3260389360735..., 0.04810773205917...)
+    (0.0530678759917..., 0.01513061504691...)
+    (0.0061658977316..., 0.00310690511463...)
+    (0.0002162629757..., 0.00021305890271...)
 
     References
     ----------
@@ -320,7 +316,7 @@ def motifs(g, k, p=1.0, motif_list=None, return_maps=False):
         out-degree-sequence, and number of edges (in this order).
     counts : list of ints
         The number of times the respective motif in the motifs list was counted
-    vertex_maps : list of lists of :class:`~graph_tool.PropertyMap` objects
+    vertex_maps : list of lists of :class:`~graph_tool.VertexPropertyMap` objects
         List for each motif graph containing the locations in the main
         graph. This is only returned if `return_maps == True`.
 
@@ -349,9 +345,9 @@ def motifs(g, k, p=1.0, motif_list=None, return_maps=False):
     >>> g = gt.random_graph(1000, lambda: (5,5))
     >>> motifs, counts = gt.motifs(gt.GraphView(g, directed=False), 4)
     >>> print(len(motifs))
-    18
+    11
     >>> print(counts)
-    [115557, 390005, 627, 700, 1681, 2815, 820, 12, 27, 44, 15, 7, 12, 4, 6, 1, 2, 1]
+    [116386, 392916, 443, 507, 2574, 1124, 741, 5, 5, 8, 2]
 
     References
     ----------
@@ -520,9 +516,9 @@ def motif_significance(g, k, n_shuffles=100, p=1.0, motif_list=None,
     >>> g = gt.random_graph(100, lambda: (3,3))
     >>> motifs, zscores = gt.motif_significance(g, 3)
     >>> print(len(motifs))
-    11
+    12
     >>> print(zscores)
-    [0.22728646681107012, 0.21409572051644973, 0.007022040788902111, 0.5872141967123348, -0.37770179603294357, -0.3484733504783734, 0.8861811801325502, -0.08, -0.2, -0.38, -0.2]
+    [2.59252643351441, 2.5966529814390387, 2.3459237708258587, -1.0829180621127024, -1.3368754665984663, -2.33027728409781, -3.055817397993647, -0.1, -0.15, -0.19, -0.4, -0.01]
 
     References
     ----------
