@@ -3,7 +3,7 @@
 #
 # graph_tool -- a general graph manipulation python module
 #
-# Copyright (C) 2006-2018 Tiago de Paula Peixoto <tiago@skewed.de>
+# Copyright (C) 2006-2019 Tiago de Paula Peixoto <tiago@skewed.de>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -44,7 +44,7 @@ from __future__ import division, absolute_import, print_function
 from .. dl_import import dl_import
 dl_import("from . import libgraph_tool_correlations")
 
-from .. import _degree, _prop
+from .. import _degree, _prop, _check_prop_scalar, VertexPropertyMap
 from numpy import *
 
 __all__ = ["assortativity", "scalar_assortativity", "corr_hist",
@@ -52,17 +52,19 @@ __all__ = ["assortativity", "scalar_assortativity", "corr_hist",
            "avg_combined_corr"]
 
 
-def assortativity(g, deg):
-    r"""
-    Obtain the assortativity coefficient for the given graph.
+def assortativity(g, deg, eweight=None):
+    r"""Obtain the assortativity coefficient for the given graph.
 
     Parameters
     ----------
     g : :class:`~graph_tool.Graph`
         Graph to be used.
-    deg : string or :class:`~graph_tool.PropertyMap`
-        degree type ("in", "out" or "total") or vertex property map, which
+    deg : string or :class:`~graph_tool.VertexPropertyMap`
+        Degree type ("in", "out" or "total") or vertex property map, which
         specifies the vertex types.
+    eweight : :class:`~graph_tool.EdgePropertyMap` (optional, default: `None`)
+        If given, this will specify the edge weights, otherwise a constant value
+        of one will be used.
 
     Returns
     -------
@@ -114,10 +116,11 @@ def assortativity(g, deg):
 
     """
     return libgraph_tool_correlations.\
-           assortativity_coefficient(g._Graph__graph, _degree(g, deg))
+           assortativity_coefficient(g._Graph__graph, _degree(g, deg),
+                                     _prop("e", g, eweight))
 
 
-def scalar_assortativity(g, deg):
+def scalar_assortativity(g, deg, eweight=None):
     r"""
     Obtain the scalar assortativity coefficient for the given graph.
 
@@ -125,9 +128,12 @@ def scalar_assortativity(g, deg):
     ----------
     g : :class:`~graph_tool.Graph`
         Graph to be used.
-    deg : string or :class:`~graph_tool.PropertyMap`
-        degree type ("in", "out" or "total") or vertex property map, which
-        specifies the vertex types.
+    deg : string or :class:`~graph_tool.VertexPropertyMap`
+        Degree type ("in", "out" or "total") or vertex property map, which
+        specifies the vertex scalar values.
+    eweight : :class:`~graph_tool.EdgePropertyMap` (optional, default: `None`)
+        If given, this will specify the edge weights, otherwise a constant value
+        of one will be used.
 
     Returns
     -------
@@ -176,9 +182,11 @@ def scalar_assortativity(g, deg):
         Phys. Rev. E 67, 026126 (2003), :doi:`10.1103/PhysRevE.67.026126`
     .. _jackknife method: http://en.wikipedia.org/wiki/Resampling_%28statistics%29#Jackknife
     """
+    if isinstance(deg, VertexPropertyMap):
+        _check_prop_scalar(deg, name="deg")
     return libgraph_tool_correlations.\
-           scalar_assortativity_coefficient(g._Graph__graph,
-                                            _degree(g, deg))
+           scalar_assortativity_coefficient(g._Graph__graph, _degree(g, deg),
+                                            _prop("e", g, eweight))
 
 
 def corr_hist(g, deg_source, deg_target, bins=[[0, 1], [0, 1]], weight=None,
@@ -190,10 +198,10 @@ def corr_hist(g, deg_source, deg_target, bins=[[0, 1], [0, 1]], weight=None,
     ----------
     g : :class:`~graph_tool.Graph`
         Graph to be used.
-    deg_source : string or :class:`~graph_tool.PropertyMap`
+    deg_source : string or :class:`~graph_tool.VertexPropertyMap`
         degree type ("in", "out" or "total") or vertex property map for the
         source vertex.
-    deg_target : string or :class:`~graph_tool.PropertyMap`
+    deg_target : string or :class:`~graph_tool.VertexPropertyMap`
         degree type ("in", "out" or "total") or vertex property map for the
         target vertex.
     bins : list of lists (optional, default: [[0, 1], [0, 1]])
@@ -298,9 +306,9 @@ def combined_corr_hist(g, deg1, deg2, bins=[[0, 1], [0, 1]], float_count=True):
     ----------
     g : :class:`~graph_tool.Graph`
         Graph to be used.
-    deg1 : string or :class:`~graph_tool.PropertyMap`
+    deg1 : string or :class:`~graph_tool.VertexPropertyMap`
         first degree type ("in", "out" or "total") or vertex property map.
-    deg2 : string or :class:`~graph_tool.PropertyMap`
+    deg2 : string or :class:`~graph_tool.VertexPropertyMap`
         second degree type ("in", "out" or "total") or vertex property map.
     bins : list of lists (optional, default: [[0, 1], [0, 1]])
         A list of bin edges to be used for the first and second degrees. If any
@@ -395,10 +403,10 @@ def avg_neighbor_corr(g, deg_source, deg_target, bins=[0, 1], weight=None):
     ----------
     g : :class:`~graph_tool.Graph`
         Graph to be used.
-    deg_source : string or :class:`~graph_tool.PropertyMap`
+    deg_source : string or :class:`~graph_tool.VertexPropertyMap`
         degree type ("in", "out" or "total") or vertex property map for the
         source vertex.
-    deg_target : string or :class:`~graph_tool.PropertyMap`
+    deg_target : string or :class:`~graph_tool.VertexPropertyMap`
         degree type ("in", "out" or "total") or vertex property map for the
         target vertex.
     bins : list (optional, default: [0, 1])
@@ -496,9 +504,9 @@ def avg_combined_corr(g, deg1, deg2, bins=[0, 1]):
     ----------
     g : :class:`~graph_tool.Graph`
         Graph to be used.
-    deg1 : string or :class:`~graph_tool.PropertyMap`
+    deg1 : string or :class:`~graph_tool.VertexPropertyMap`
         first degree type ("in", "out" or "total") or vertex property map.
-    deg2 : string or :class:`~graph_tool.PropertyMap`
+    deg2 : string or :class:`~graph_tool.VertexPropertyMap`
         second degree type ("in", "out" or "total") or vertex property map.
     bins : list (optional, default: [0, 1])
         Bins to be used for the first degrees. If the list has size 2, it is
